uniform sampler2D texture;
uniform float amplitude;          // Amplitude of distortion
uniform float frequency;          // Frequency of distortion
uniform float time;              // Time variable for animation

void main()
{
    // Get the original texture coordinate
    vec2 originalTexCoord = gl_TexCoord[0].xy;
    
    // Distort the texture coordinate using sine wave functions
    vec2 distortedTexCoord;
    distortedTexCoord.x = originalTexCoord.x + amplitude * sin(2.0 * 3.14159 * frequency * originalTexCoord.y + time);
    distortedTexCoord.y = originalTexCoord.y + amplitude * sin(2.0 * 3.14159 * frequency * originalTexCoord.x + time);
    
    // Clamp the distorted texture coordinate to avoid texture wrapping
    distortedTexCoord = clamp(distortedTexCoord, 0.0, 1.0);
    
    // Sample the texture using the distorted texture coordinate
    vec4 pixel = texture2D(texture, distortedTexCoord);
    
    // Output the final color
    gl_FragColor = gl_Color * pixel;
}
